# cliwiper
A Basic cli cleaner in the form as a cross-platform Python module that provides a function which clears the terminal.  
**This is a simpler alternative to defining this function on your own**.  

# Installation
To install with pip, or pipx run:  

`pip install cliwiper`  
`pipx install cliwiper`  

# Usages  

```
from cliwiper import wiper  
```

```
wiper()  
```

# License  
This project is licensed under the terms of the [MIT license](#LICENSE).  
